Module round

Module round 

Rounding modes re-exported from dashu-float so callers do not need a direct dependency on dashu-float for basic rounding-mode selection.

Structs

Down
Round toward -∞
HalfAway
Round to the nearest value, ties away from zero
HalfEven
Round to the nearest value, ties are rounded to an even value. (default mode for decimal float)
Up
Round toward +∞
Zero
Round toward 0 (default mode for binary float)